// Listado: main.cpp
//
// Ejercicio 2. Implementación de colisiones 
// entre dos circunferencias

#include <iostream>
#include <SDL/SDL.h>
#include <SDL/SDL_ttf.h>


#include "Miscelanea.h"
#include "Teclado.h"
#include "Personaje.h"
#include "Colisiones.h"

using namespace std;

int main() {

    SDL_Surface *pantalla, *imagen;

    // Inicializamos SDL y establecemos el modo de video

    if(inicializar_SDL(&pantalla, "Colisiones")) {

	cerr << "No se puede inicializar SDL" << SDL_GetError() << endl;
        exit(1);
	
    }


    // Inicializamos la librería TTF

    if(TTF_Init() == 0) {

	atexit(TTF_Quit);
        cout << "TTF inicializada" << endl;
	
    }

    SDL_Rect fondo;
    // Cargamos el fondo
    //Fondo("./Imagenes/fondo.bmp",0,0, imagen, pantalla);
        imagen = SDL_LoadBMP("./Imagenes/fondo.bmp");
    
    fondo.x = 0;
    fondo.y = 0;
    fondo.w = imagen->w;  // Longitud del ancho de la imagen
    fondo.h = imagen->h;  // Longitud del alto de la imagen
    SDL_BlitSurface(imagen, NULL, pantalla, &fondo);
    // Cargamos la imagen
    if(imagen == NULL) {
		fprintf(stderr, "No se puede cargar la imagen: %s\n", SDL_GetError());
		exit(1);
    }
    TTF_Font *fuente;
    // Copiamos la superficie creada rectángulo en la anterior pantalla
    SDL_BlitSurface(imagen, NULL, pantalla, &fondo);
    fuente = TTF_OpenFont("Fuentes/ep.ttf", 40);

    SDL_Color color;

    // Establecemos el color para la fuente

    color.r = 250;
    color.g = 100;
    color.b = 0;

    


    //PERSONAJE PRINCIPAL
    // Teclado para controlar al personaje
    
    Teclado teclado;

    // Cargamos los personajes para las colisiones en sus posiciones

    Personaje principal("./Imagenes/heroe.bmp", 5, 365);
    Personaje adversario("./Imagenes/sordao.bmp", 800, 365);
    Personaje pelota("./Imagenes/pelota_voley.bmp", 150, 50);
    // Componemos los personajes

    // Vamos a contruir el área de colisión a partir de rectángulos
    // para el personaje principal

    SDL_Rect rect_principal[3] = {{58, 5, 41, 35},
				  {34, 39, 37, 32},
				  {30, 72, 46, 24}};


    for(int i = 0; i < 3; i++)
	principal.annadir_rectangulo(rect_principal[i]);

    
    // Vamos a contruir el área de colisión a partir de rectángulos
    // para el adversario

    SDL_Rect rect_adversario[1] = {{25, 2, 48, 94}}; 
    
    for(int i = 0; i < 1; i++)
	adversario.annadir_rectangulo(rect_adversario[i]);   
    

    // Los mostramos por pantalla
    
    principal.dibujar(pantalla);
    adversario.dibujar(pantalla);
    pelota.dibujar(pantalla);

    SDL_Flip(pantalla);

    // Variables auxiliares

    bool terminar = false;
    bool salto = false;
    bool caida = false;
    bool salto1 = false;
    bool caida1 = false;

    int limite_izq=1, limite_der=930;
    int x0, y0, x1, y1;
    
    SDL_Rect pos_texto;

    pos_texto.x = 200;
    pos_texto.y = 75;

    // Game loop PARA DOS PLAYERS

    while(terminar == false) {

	// Actualizamos el estado del teclado

	teclado.actualizar();

	// Variables de control para saber si 
	// tenemos que refrescar la pantalla o no

	x0 = principal.pos_x();
	y0 = principal.pos_y();
	x1 = adversario.pos_x();
	y1 = adversario.pos_y();
	//No puede estar cayendo cuando saltemos 
	if ( teclado.pulso(Teclado::TECLA_SALTAR) && !caida )
	{
	  salto=true;

	}
	if ( teclado.pulso(Teclado::TECLA_SALTAR1) && !caida1 )
	{
	  salto1=true;

	}	  
	if(teclado.pulso(Teclado::TECLA_IZQUIERDA) && principal.pos_x()>limite_izq) {

	    principal.retrasar_x();

	}
	if(teclado.pulso(Teclado::TECLA_IZQUIERDA1) && adversario.pos_x()>limite_izq) {

	    adversario.retrasar_x();

	}
	if(teclado.pulso(Teclado::TECLA_DERECHA) && principal.pos_x()<limite_der) {

	    principal.avanzar_x();

	}
	if(teclado.pulso(Teclado::TECLA_DERECHA1) && adversario.pos_x()<limite_der) {

	    adversario.avanzar_x();

	}
	if (salto)
	{
	  principal.subir_y();
	  if ( principal.pos_y() < 250)
	  {
	    salto = false;
	    caida = true;
	  }

	}

	if (caida)
	{
	  principal.bajar_y();
	  if(principal.pos_y() > 365)
	  {
	    principal.pos_y(365);
	    caida = false;
	  }
	}
	if (salto1)
	{
	  adversario.subir_y();
	  if ( adversario.pos_y() < 250)
	  {
	    salto1 = false;
	    caida1 = true;
	  }

	}

	if (caida1)
	{
	  adversario.bajar_y();
	  if(adversario.pos_y() > 365)
	  {
	    adversario.pos_y(365);
	    caida1 = false;
	  }
	}       
	// Dibujamos a los personajes
	// en su nuevas posiciones
	
	Uint32 negro = SDL_MapRGB(pantalla->format, 0, 0, 0);
	SDL_FillRect(pantalla, NULL, negro);
	SDL_BlitSurface(imagen, NULL, pantalla, &fondo);
	
	
	principal.dibujar(pantalla);
	adversario.dibujar(pantalla);
	pelota.dibujar(pantalla);

	// Comprobamos si existe colision

	if(colision(principal, adversario))
	    SDL_BlitSurface(TTF_RenderText_Blended(fuente, "Colision",color),NULL,pantalla,&pos_texto);

	// Actualizamos la pantalla

	SDL_Flip(pantalla);
				

	// Función auxiliar que
	// controla si existen eventos de salida

	if(eventos_salida() == 0)
	    terminar = 1;
	
    }
    SDL_FreeSurface(imagen);
    return 0;

}


